# Turrican Rotary Saw package

![](https://turrican.uraanikaivos.com/rotarysawturrican.png)

General utilities and import collections for my scripts and doodads. They won't be useful to anyone else but that might change in the future.
